@@ -22,7 +22,7 @@ def verbose_print(s: str):
     log.debug(s)
     global verbose
     if verbose is None:
-        verbose = os.environ["DH_VERBOSE"] if "DH_VERBOSE" in os.environ else False
+        verbose = os.environ['DH_VERBOSE'] if 'DH_VERBOSE' in os.environ else False
     if verbose:
         click.echo(s)
 
