@@ -449,18 +449,18 @@ class DebHelper:
         """
 
         def expand_variables(bits: list[str]) -> list[str]:
-            """ Helper fn. Do variable expansion on filepaths """
+            """Helper fn. Do variable expansion on filepaths"""
             new_bits = []
             for fpath in bits:
                 new_fpath = []
-                for elm in fpath.split('/'):
+                for elm in fpath.split("/"):
                     if elm.startswith("$"):
                         # TODO
                         pass
                     new_fpath.append(elm)
                 new_bits.append("/".join(new_fpath))
-            return new_bits                                   
-                
+            return new_bits
+
         # Reads in the specified file, one line at a time. splits on words
         # If a value is passed in as the second parameter, then glob
         # expansion is done in the directory specified by the parameter ("." is
@@ -525,7 +525,6 @@ class DebHelper:
         for package, _ in self.packages.items():
             with open(f"debian/{package}.debhelper.log", "a", encoding="utf-8") as f:
                 f.write(self.tool_name + "\n")
-        
 
     def save(self):
         self.save_substvars()
