@@ -15,7 +15,7 @@ my $tmpdir = "debian/tmp";
 if (@packages == 1) {
     $tmpdir = $packages[0];
 }
-warning("DEBUG: running with tmpdir $tmpdir");
+# warning("DEBUG: running with tmpdir $tmpdir");
 
 # dwz will exit 1, breaking on patchelf
 remove_command('dh_dwz');
